@@ -4,7 +4,7 @@ from functools import wraps
 from six.moves.urllib.request import urlopen
 
 import rsa
-import jwt
+from jose import jwt
 from flask import request, jsonify, _request_ctx_stack
 
 
@@ -103,7 +103,7 @@ class AuthHelper:
 
             return None  # an rsa key matching the desired kid was not found -> return None
 
-        except jwt.DecodeError as ex:
+        except jwt.JWTError as ex:
             raise AuthError({
                 'code': 'invalid_error',
                 'description': 'Unable to decode the provided auth token'
@@ -121,10 +121,10 @@ class AuthHelper:
                     'code': 'token_invalid',
                     'description': 'Can only decode RSA auth tokens at this time.'
                 }, 401)
-            rsa_key_pem = rsa.PublicKey(rsa_key['n'], rsa_key['e']).save_pkcs1()
+
             payload = jwt.decode(
                 token,
-                rsa_key_pem,
+                rsa_key,
                 algorithms=self.__algorithms,
                 audience=self.__audience,
                 issuer=f'https://{self.__auth0_domain}/'
@@ -136,18 +136,12 @@ class AuthHelper:
                 'description': 'Auth token is expired'
             }, 401) from ex
 
-        except jwt.InvalidAudienceError as ex:
+        except jwt.JWTClaimsError as ex:
             raise AuthError({
                 'code': 'invalid_claims',
                 'description': 'Invalid claims, please check audience claim'
             }, 401) from ex
 
-        except jwt.InvalidIssuerError as ex:
-            raise AuthError({
-                'code': 'invalid_claims',
-                'description': 'Invalid claims, please check issuer claim'
-            }, 401) from ex
-
         return payload
 
     def requires_scope(self, required_scope: str) -> bool:
@@ -156,9 +150,11 @@ class AuthHelper:
         :param required_scope: str, the scope required to access the resource
         """
         token = self.get_token_auth_header()
-        unverified_claims = jwt.decode(token, verify=False)
+        unverified_claims = jwt.get_unverified_claims(token)
+
         if unverified_claims.get('scope', None):
             token_scopes = unverified_claims['scope'].split()
+
             for token_scope in token_scopes:
                 if token_scope == required_scope:
                     return True
