@@ -96,7 +96,7 @@ def test_get_rsa_key_from_unverified_token(mocker):
     mock_url_open = mocker.patch('busie_flask.auth.urlopen')
     mock_json = mocker.patch('busie_flask.auth.json')
     mock_jwt = mocker.patch('busie_flask.auth.jwt')
-    mock_jwt.DecodeError = Exception
+    mock_jwt.JWTError = Exception
     mock_domain = 'foobar.com'
     mock_token = 'sometokendoesntmatteraslongasitsastring'
     mock_jwk = {'kid': 'someKID', 'kty': 'someKTY', 'use': 'someUSE', 'n': 'n', 'e': 'e'}
@@ -124,25 +124,22 @@ def test_get_rsa_key_from_unverified_token(mocker):
     mock_jwt.get_unverified_header.return_value = {'kid': 'invalid'}
     assert auth.get_rsa_key_from_unverified_token(mock_token) is None
 
-    mock_jwt.get_unverified_header.side_effect = mock_jwt.DecodeError
+    mock_jwt.get_unverified_header.side_effect = mock_jwt.JWTError
     with pytest.raises(AuthError):
         auth.get_rsa_key_from_unverified_token(mock_token)
 
 def test_handle_rsa_decode(mocker):
     """
     - Raise AuthError on token expired
-    - Raise AuthError on InvalidAudience
-    - Raise AuthError on invalid issuer
+    - Raise AuthError on InvalidClaimsError
     - return the decoded token object
     """
     mock_jwt = mocker.patch('busie_flask.auth.jwt')
-    mock_rsa = mocker.patch('busie_flask.auth.rsa')
     class MockExpiredSignature(Exception):
         """Mock Expired Signature Error"""
-    class MockInvalidAudience(Exception):
-        """Mock Invalid Audience Error"""
-    class MockInvalidIssuer(Exception):
-        """Mock Invalid Issuer Errror"""
+    class MockInvalidClaims(Exception):
+        """Mock Invalid Claims Error"""
+
     mock_token = 'sometoken'
     mock_key = {'alg': 'RS256', 'use': 'sig', 'n': 'thenvalue', 'e': 'theevalue'}
     mock_algorithms = ['algos']
@@ -154,11 +151,9 @@ def test_handle_rsa_decode(mocker):
     auth._AuthHelper__audience = mock_audience
 
     decoded = auth.handle_rsa_decode(mock_key, mock_token)
-    mock_rsa.PublicKey.assert_called_once_with(mock_key['n'], mock_key['e'])
-    mock_rsa.PublicKey.return_value.save_pkcs1.assert_called_once()
     mock_jwt.decode.assert_called_once_with(
         mock_token,
-        mock_rsa.PublicKey.return_value.save_pkcs1.return_value,
+        mock_key,
         algorithms=mock_algorithms,
         audience=mock_audience,
         issuer=f'https://{mock_domain}/'
@@ -166,9 +161,8 @@ def test_handle_rsa_decode(mocker):
     assert decoded == mock_jwt.decode.return_value
 
     mock_jwt.ExpiredSignatureError = MockExpiredSignature
-    mock_jwt.InvalidAudienceError = MockInvalidAudience
-    mock_jwt.InvalidIssuerError = MockInvalidIssuer
-    exceptions = [mock_jwt.ExpiredSignatureError, mock_jwt.InvalidAudienceError, mock_jwt.InvalidIssuerError, AuthError]
+    mock_jwt.JWTClaimsError = MockInvalidClaims
+    exceptions = [mock_jwt.ExpiredSignatureError, mock_jwt.JWTClaimsError, AuthError]
     for e in exceptions:
         mock_jwt.decode.side_effect = e
         args_list = [
@@ -226,13 +220,13 @@ def test_requires_scope(mocker):
     mock_get_token = mocker.patch('busie_flask.auth.AuthHelper.get_token_auth_header')
     mock_get_token.return_value = mock_token
     mock_jwt = mocker.patch('busie_flask.auth.jwt')
-    mock_jwt.decode.return_value = {'scope': 'foo bar foobar'}
+    mock_jwt.get_unverified_claims.return_value = {'scope': 'foo bar foobar'}
 
     auth = AuthHelper()
     assert auth.requires_scope('foo')
     mock_get_token.assert_called_once()
-    mock_jwt.decode.assert_called_once_with(mock_token, verify=False)
+    mock_jwt.get_unverified_claims.assert_called_once_with(mock_token)
 
     assert not auth.requires_scope('somethingnotthere')
-    mock_jwt.decode.return_value = {}
+    mock_jwt.get_unverified_claims.return_value = {}
     assert not auth.requires_scope('foo')
